@@ -43,7 +43,7 @@ class Storage(Step):
 
     def store(self, media: Media, url: str) -> None:
         if media.is_stored(): 
-            logger.debug(f"{self.key} already stored, skipping")
+            logger.debug(f"{media.key} already stored, skipping")
             return
         self.set_key(media, url)
         self.upload(media)
@@ -77,7 +77,7 @@ class Storage(Step):
         # filename_generator logic
         if self.filename_generator == "random": filename = str(uuid.uuid4())[:16]
         elif self.filename_generator == "static":
-            he = HashEnricher({"hash_enricher": {"algorithm": "SHA-256", "chunksize": 1.6e7}})
+            he = HashEnricher({"hash_enricher": {"algorithm": ArchivingContext.get("hash_enricher.algorithm"), "chunksize": 1.6e7}})
             hd = he.calculate_hash(media.filename)
             filename = hd[:24]
 
